%% Smoking_Optimization_Code.m
% The following code generates all the Figures and Tables in the main text
% and makes use of the supporting m-files
%   - multi_NLLS_smk2: This program is used to fit the data to the model
%   - multi_OBJ_smk: Objective function when optimizing local parameters
%   - multi_OBJ_all_smk2: Objective function when optimizing global
%   parameters
%   - multi_smk: definition of ODE (Eq. 1 subject to Eq. 2)

%% Step 1: Load Data
% Variable name: Articles_Scopus
% Proxy data for knowledge about health effects of smoking
% - 3 columns: [Year, No. of Articles, Cumulative No. of Articles]
load('Articles_Scopus')

% Variable name: USPop
% - 2 columns: [Year, US population]
load('USPop')

% Variable name CandP
% Raw cigarette consumption in g per person per day (c) and 
% smoking prevalence (x) by country
% - 4 column cell array: [Name of Country (String), c, x, IDV]
% - we add 3 additional columns: [t_max, c_max, c_start]
%   - t_max is the year in which c peaks
%   - c_max = c(t_max)
load('RawCandP')

% total number of countries
N = size(CandP,1);      

% Remove x(1960) = 0.32 from France's data, as it is an outlier.
idx_FRA = find(strcmp(CandP(:,1),'FRA'),1);
CandP{idx_FRA,3}(1,:) = [];

%% Step 2: Establish Tables A.1 and A.3 (summaries of raw data)
% Table A.1, data summary: first year x observed, last year x observed,
% no. obs. for x, first year c observed, last year c observed, 
% no. obs. for c
Table_A1 = cell(N+1,7);  
Table_A1(1,:) = {'Country','1st year x obs.','last year x obs.',...
    'no. obs. for x', '1st year c obs.', 'last year c obs.',...
    'no. obs. for c'};
Table_A1(2:end,1) = CandP(:,1);

for i = 1:N
    % find maximum consumption for each country
    c_max = max(CandP{i,2}(:,2));
    CandP{i,6} = c_max;
    
    % find peak year in maximum consumption for each country
    t_max = find(CandP{i,2}(:,2)==c_max, 1);
    CandP{i,5} = CandP{i,2}(t_max,1);
    
    % If prevalence data is available, add to Table A.1
    if ~isempty(CandP{i,3})
        Table_A1{i+1,2} = CandP{i,3}(1,1);
        Table_A1{i+1,3} = CandP{i,3}(end,1);
        Table_A1{i+1,4} = length(CandP{i,3});
    end
    
    % If consumption data is available, add to Table A.1
    if ~isempty(CandP{i,2})
        Table_A1{i+1,5} = CandP{i,2}(1,1);
        Table_A1{i+1,6} = CandP{i,2}(end,1);
        Table_A1{i+1,7} = length(CandP{i,2});
    end
end

% Table A.3: IDV and peak year (tmax)
Table_A3 = cell(N+1,3);
Table_A3(1,:) = {'Country', 'IDV', 'tmax'};
Table_A3(2:end,:) = CandP(:,[1,4,5]);

%% Step 3. Calculate B and C using linear regression x = Cc + B
% Store results in Table A.2: [C, C_int, B, B_int, R^2, p, n_obs]
Table_A2 = cell(N+1,8);
Table_A2(1,:) = {'Country', 'C^', '95% CI for C^', 'B^',...
    '95% CI for B^', 'R^2', 'p', 'n_obs'};
Table_A2(2:end,1) = CandP(:,1);

% Record the indices of countries whose B and C (from the linear regression
% x = Cc + B) have high R^2, significant Pearson's correlation p,
% and sufficient observations
Rsq_thresh = 0.70;
p_thresh = 0.001;
n_obs_thresh = 15;

% 1 for countries who are significant according to thresholds above, 0 o/w
sig_cty = zeros(N,1);

% Perform regression for each country
for i=1:N
    % Only proceed if both x and c data are available
    if ~isempty(CandP{i,2}) && ~isempty(CandP{i,3})
        % Find years where both x and c are recorded
        x = CandP{i,3}(:,2);
        c = zeros(length(x),1);
                
        for j = 1:length(x)
            c_idx = find(CandP{i,3}(j,1)==CandP{i,2}(:,1), 1);
            
            if ~isempty(c_idx)
                c(j) = CandP{i,2}(c_idx,2);
            end
        end
        
        % Get rid of unused elements of x and c
        x(c==0)=[];
        c(c==0)=[];
        
        % Record number of year where both x and c are observed in Tab. A.2
        Table_A2{i+1,8} = length(x);
        
        % Regress x on c and record coeff./con. int./corr. in Tab. A.2
        if length(x) > 2
            [b_temp, b_int] = regress(x, [c, ones(length(c),1)]);
            Table_A2{i+1,2} = b_temp(1);
            Table_A2{i+1,4} = b_temp(2);
            Table_A2{i+1,3} = 0.5*(b_int(1,2)-b_int(1,1))';
            Table_A2{i+1,5} = 0.5*(b_int(2,2)-b_int(2,1))';
            
            [r,p] = corrcoef([x,c]);
            Table_A2{i+1,6} = r(1,2)^2;
            Table_A2{i+1,7} = p(1,2);
            
            % Pick out significant relationships
            % Plot results (legend is applied outside of loop, below)
            if Table_A2{i+1,7} <= p_thresh && ...
                    Table_A2{i+1,8} >= n_obs_thresh &&...
                    Table_A2{i+1,6} >= Rsq_thresh
                sig_cty(i) = 1;
            end
        end
    end
end

% Make sure that sig_cty is logical (not double or integer)
sig_cty = logical(sig_cty);

% Indices of significant countries in CandP and BandC
idx_sig_cty = find(sig_cty==1);

% No. of countries with significant BandC
N_sig = sum(sig_cty);  

%% Step 4: Estimate prevalence x_hat using significant linear regressions
% Store x_hat in P: 
%   [Country names, x_hat, x, IDV, t_max, x_hat_max, x_hat(t_start)]
P = CandP(sig_cty,:);

% Earliest time that significant countries have a c (or x_hat)
% measurement.
t_start = zeros(N_sig,1);

for i=1:N_sig
    t_start(i) = P{i,2}(1,1);
    
    % Calculate prevalence x_hat and store in P
    B = Table_A2{idx_sig_cty(i)+1,4};
    C = Table_A2{idx_sig_cty(i)+1,2};
    
    P{i,2}(:,2) = C*P{i,2}(:,2) + B;
    
    % Calculate x_hat_max and store in P
    P{i,6} = C*P{i,6} + B;
end

% Earliest time that all significant countries have a c (or x_hat)
% measurement.
t_start = max(t_start);

% Calculate x_hat(t_start)
for i=1:N_sig
    idx_t_start = find(P{i,2}(:,1)==t_start);
    
    % If x_hat(t_start) is not recorded, use linear interpolation
    if ~isempty(idx_t_start)
        P{i,7} = P{i,2}(idx_t_start, 2);
    else
        idx_t_start = find(P{i,2}(:,1) > t_start, 1);
        t2 = P{i,2}(idx_t_start,1);
        t1 = P{i,2}(idx_t_start-1,1);
        
        y2 = P{i,2}(idx_t_start,2);
        y1 = P{i,2}(idx_t_start-1,2);
        
        P{i,7} = y2*(t_start - t1)/(t2-t1) + y1*(t2 - t_start)/(t2-t1);
    end
end

%% Step 5: Fit model to data P
% Initialize parameters for model fitting
global Tx Lparam bounds model_no knowl

Tx = P(:,1:2);                      % data
Lparam = zeros(N_sig,6);            % [x0, a, b, u_0, u_inf, delta/t*]
knowl = articles_Scopus(:,[1 3]);

for i = 1:N_sig
    Lparam(i,1) = Tx{i,2}(1,2);
end

Lparam(:,[2 3]) = 1;
Lparam(:,4) = 0.51;
Lparam(:,5) = 0.49;

% Choose which model to use.
% Model 1 is step function, model 2 is discounting model
model_no = 2;

if model_no == 1
    bounds = [[zeros(1,5), 1960]; [1, 2, 2, 1, 1, 1980]];
    Lparam(:,6) = 1975;
elseif model_no == 2
    bounds = [zeros(1,6); [1, 2, 2, 1, 1, 1]];
    Lparam(:,6) = 0.9985;
end

% Set which variables are global and which are fixed
% [x0 a b u_0 u_inf delta]
glob_var = [0 0 1 0 0 1];
fix_var = [0 0 0 0 0 0];

% Optimization parameters: Stop when 
% - change in obj. function is <= tol, or
% after max_itn iterations
tol = 10^(-6);
max_itn = 150;

% Final year to compute the solution to the ODE (i.e. solution to ODE is
% calculated from the first year for which x_hat is available until
% plt_int).
plt_int = 2020;

% Perform fitting procedure
[S_sig, error_sig, fit_sig, xstar_sig, DS_sig] = ...
    multi_NLLS_smk2(glob_var, fix_var, tol, max_itn, 0, plt_int);

% Store results in Table 1: [parameters and local errors; total error]
Table_1 = cell(N_sig+2,9);
Table_1(1,:) = {'Country', 'x0', 'a', 'b', 'u_0', 'u_infty',...
    'delta', 'Ei2', 'Ei1'}; 
Table_1{end,1} = 'E2';

for i=1:N_sig
    Table_1{i+1,1} = CandP(idx_sig_cty(i),1);
    Table_1{i+1,9} = error_sig(i,1)/CandP{idx_sig_cty(i),7};
    Table_1{i+1,8} = error_sig(i,2);
    
    for j=1:6       
        Table_1{i+1,j+1} = Lparam(i,j);
    end
end

Table_1{end,8} = sum(error_sig(:,2));

% Plot Fig A.1: x vs. year and c vs. year for significant countries
figure

% position for figure on screen
set(gcf, 'units', 'centimeters', 'pos', [-5 -5 17.5 25])

% position for panels within figure
pos = [1 5 8 12 15 19 24];

% xmin, xmax, ymin, and ymax for significant countries:
% - Aus, Can, Fra, Nzl, Swe, UK, US
xmin = [1920 1920 1900 1920 1920 1900 1920];
xmax = 2020;

ymin = [[0 0]; [0 -2]; [0 -11]; [0 -10]; [0 -1]; [0 0]; [0 0]];
ymax = [[0.54 12]; [0.54 14]; [0.54 20]; [0.54 18]; [0.54 9]; [0.54 10]; [0.54 15]];

% titles for panels in figure
tit = {'{\bf (a)} Australia', '{\bf (b)} Canada', '{\bf (c)} France',...
    '{\bf (d)} New Zealand', '{\bf (e)} Sweden', '{\bf (f)} United Kingdom',...
    '{\bf (g)} United States'};

% Plot Fig. A.1
for i=1:N_sig
    % position of panel within figure
    subplot(4,7,pos(i):(pos(i)+2))
    
    box on
    % plot
    [AX, H1, H2] = plotyy(CandP{idx_sig_cty(i),3}(:,1), CandP{idx_sig_cty(i),3}(:,2),...
        CandP{idx_sig_cty(i),2}(:,1), CandP{idx_sig_cty(i),2}(:,2));
    
    % plot outlier in the case of France
    if strcmp(CandP{idx_sig_cty(i),1},'FRA')
        hold on
        plot([1960, CandP{idx_sig_cty(i),3}(1,1)],...
            [0.32, CandP{idx_sig_cty(i),3}(1,2)], 'LineWidth', 1, 'Color', 'blue')
        scatter(1960,0.32,36,'red','*')
    end
    
    % add title
    title(tit(i),'FontSize', 9)
    
    % set markers and line styles
    set(H1,'LineWidth',1,'Marker','*')
    set(H2,'LineWidth',1,'Color','black','Marker','.','Linestyle',':')
    
    % set axes labels and tick marks
    axis(AX(1),[xmin(i), xmax, ymin(i,1), ymax(i,1)])
    axis(AX(2),[xmin(i), xmax, ymin(i,2), ymax(i,2)])
    set(AX(2),'YColor','black')
    
    set(get(AX(1),'Ylabel'),'String','Smoking prevalence ($x$)','FontSize',8,'Interpreter','Latex')
    
    set(get(AX(2),'Ylabel'),'String','Cig. con. (g)/person/day ($c$)', 'FontSize',8,'Color','black','Interpreter','Latex')
    
    set(get(AX(1),'Xlabel'),'String','Year','FontSize',8,'Interpreter','Latex')
    
    set(AX(1),'FontSize',6,'XTick',xmin(i):25:xmax,'XTickLabel',...
        {num2str(xmin(i)), num2str(xmin(i)+25), num2str(xmin(i)+50), num2str(xmin(i)+75), num2str(xmax)})
    set(AX(2),'FontSize',6,'XTick',xmin(i):(xmax-xmin(i))/6:xmax,'XTickLabel',...
        {num2str(xmin(i)), '', '', '', '', '', num2str(xmax)})
    
    set(AX(1),'FontSize',6,'YTick',ymin(i,1):(ymax(i,1)-ymin(i,1))/6:ymax(i,1),'YTickLabel',...
        {num2str(ymin(i,1)), '', '', num2str((ymax(i,1)+ymin(i,1))/2), '', '', num2str(ymax(i,1))})
    set(AX(2),'FontSize',6,'YTick',ymin(i,2):(ymax(i,2)-ymin(i,2))/6:ymax(i,2),'YTickLabel',...
        {num2str(ymin(i,2)), '', '', num2str((ymax(i,2)+ymin(i,2))/2), '', '', num2str(ymax(i,2))})
end

% Plot Fig A.2: x (output of model) and xhat vs. year for sig. countries
% use same pos, xmin, xmax, ymin, ymax, tit as Fig. A.1
figure

% position of figure on screen
set(gcf, 'units', 'centimeters', 'pos', [-5 -5 25 40])

for i=1:N_sig
    % position of panel in figure
    subplot(4,7,pos(i):(pos(i)+2))
    
    box on; hold on;
    
    % plot
    plot(fit_sig{i}(:,1), fit_sig{i}(:,2), 'LineWidth', 1, 'Color','black');
    scatter(P{i,2}(:,1), P{i,2}(:,2), 'blue', '.')
    
    % add title, axes labels, tick marks
    title(tit(i),'FontSize', 9)
    xlabel('Year', 'FontSize', 8, 'Interpreter', 'Latex')
    ylabel('Est. smoking prevalence ($\hat{x}$)','FontSize',8,'Interpreter','Latex')
    axis([xmin(i), xmax, ymin(i,1), ymax(i,1)])
    
    set(gca,'FontSize',6,'XTick',xmin(i):(xmax-xmin(i))/6:xmax,'XTickLabel',...
        {num2str(xmin(i)), '', '', '', '', '', num2str(xmax)})
    
    set(gca,'FontSize',6,'YTick',ymin(i,1):(ymax(i,1)-ymin(i,1))/6:ymax(i,1),'YTickLabel',...
        {num2str(ymin(i,1)), '', '', num2str((ymax(i,1)+ymin(i,1))/2), '', '', num2str(ymax(i,1))})
end

%% Step 6. Correlations between a, IDV, x_hat_max, s_x, t_max
% correlations between (row, column) are stored in Table_2{:,:,1}
% p values are stored in Table_2{:,:,2}
% rows: a, IDV, x_max, t_max
% columns: IDV, x_max, t_max, s_x, t_max_all
Table_2 = cell(5,6,2);
Table_2(1,2:6,1) = {'IDV', 'x_max', 't_max', 's_x', 't_max (all)'};
Table_2(2:5,1,1) = {'a', 'IDV', 'x_max', 't_max'};

Table_2(1,2:6,2) = {'IDV', 'x_max', 't_max', 's_x', 't_max (all)'};
Table_2(2:5,1,2) = {'a', 'IDV', 'x_max', 't_max'};

% Calculate s_x
% s_x = (x_max - x(start))/(t_max - start)
s_x = ([P{:,6}]' - [P{:,7}]')./([P{:,5}]' - t_start);

% Values for significant countries
% X = [a, IDV, x_max, t_max, s_x]
X = [[Table_1{2:end-1,3}]', [P{:,4}]', [P{:,6}]', [P{:,5}]', s_x];

% Compute correlations for sig. countries
[c_tmp, c_p_tmp] = corrcoef(X);

% Store correlations for sig. countries
for i=1:5
    for j=i+1:5
        Table_2{i+1,j,1} = c_tmp(i,j);
        Table_2{i+1,j,2} = c_p_tmp(i,j);
    end
end

% Values for all countries
% X_all = [IDV, t_max]
X_all = [[CandP{:,4}]',[CandP{:,5}]'];

% Compute correlations for all countries
[corr_values_IDV_tmax, corr_p_IDV_tmax] = corrcoef(X_all);

% Store correlations for all countries
Table_2{3,6,1} = corr_values_IDV_tmax(1,2);
Table_2{3,6,2} = corr_p_IDV_tmax(1,2);

% Plot Fig. 1
% new figure
figure
hold on; box on;

% plot USA and SWE in first panel
idx_USA_P = find(strcmp(P(:,1),'USA'),1);
idx_SWE_P = find(strcmp(P(:,1),'SWE'),1);

% set size of figure and panels
set(gcf, 'units', 'centimeters', 'pos', [1 1 8.75 8.5])
set(gca, 'units', 'centimeters', 'pos', [1.75 1 6.5 6.75])

% plot line of best fit from model
% scatter estimated smoking prevalence
plot(fit_sig{idx_SWE_P}(:,1), fit_sig{idx_SWE_P}(:,2), 'Color', 'black', 'LineWidth', 1)
scatter(P{idx_SWE_P,2}(:,1), P{idx_SWE_P,2}(:,2), '*', 'blue')

plot(fit_sig{idx_USA_P}(:,1), fit_sig{idx_USA_P}(:,2), 'Color', 'black', 'LineWidth', 1)
scatter(P{idx_USA_P,2}(:,1), P{idx_USA_P,2}(:,2), '.', 'red')

% label axes
xlabel('Year','FontSize',12, 'Interpreter', 'Latex')
ylabel('Est. smoking prevalence ($\hat{x}$)','FontSize',12, 'Interpreter', 'Latex')

% set limits and ticks for axes
xmin = 1920;
xmax = 2010;
ymin = 0.05;
ymax = 0.4;

axis([xmin, xmax, ymin, ymax])

set(gca,'YTick', ymin:(ymax-ymin)/6:ymax)
set(gca,'YTickLabel',{num2str(ymin), '', '', num2str((ymax+ymin)/2), '', '', num2str(ymax)})

set(gca,'XTick', xmin:(xmax-xmin)/6:xmax)
set(gca,'XTickLabel',{num2str(xmin), '', '', num2str((xmax+xmin)/2), '', '', num2str(xmax)})

% Plot Fig. 4: a vs IDV and s_x vs IDV
figure
set(gcf, 'units', 'centimeters', 'pos', [1 1 17.5 8.5])

for i = [1 5]
    % location, y labels and ticks, title, and position of panels
    if i==1
        subplot(1,2,1)        
        ylabel('Relative conformity ($a$)','FontSize',12,'Interpreter','Latex')
        ymin = 0.9;
        ymax = 1.15;
        title('{\bf(a)}','FontSize',12)
        set(gca, 'units', 'centimeters', 'pos', [1.75 1 6.5 6.75])
    else
        subplot(1,2,2)
        ylabel('Average slope ($s_x$)','FontSize',12,'Interpreter','Latex')
        ymin = 0;
        ymax = 0.008;
        title('{\bf(b)}','FontSize',12)
        set(gca, 'units', 'centimeters', 'pos', [10.75 1 6.5 6.75])
    end
    
    box on; hold on;
    
    % axes limits
    xmin = 65;
    xmax = 95;
    
    axis([xmin xmax ymin ymax])
    
    % scatter a (or s_x) versus IDV
    scatter(X(:,2),X(:,i),'.')
    
    % add text identifiers
    text(X(:,2)+1,X(:,i), P(:,1))
    
    % plot line of best fit
    c = regress(X(:,i), [X(:,2), ones(length(X),1)]);
    
    IDV = xmin:xmax;
    plot(IDV, IDV*c(1) + c(2),'LineWidth',1,'Color','black')
    
    % labels, ticks    
    xlabel('Individualism (IDV)','FontSize',12,'Interpreter','Latex')
    set(gca,'XTick', xmin:(xmax-xmin)/6:xmax)
    set(gca,'XTickLabel',{num2str(xmin), '', '', num2str((xmax+xmin)/2), '', '', num2str(xmax)})
    
    set(gca,'YTick', ymin:(ymax-ymin)/6:ymax)
    set(gca,'YTickLabel',{num2str(ymin), '', '', num2str((ymax+ymin)/2), '', '', num2str(ymax)})
end

% Plot Fig. 6: t_max vs IDV in all countries
figure
hold on; box on;
set(gcf, 'units', 'centimeters', 'pos', [1 1 9 8.5])

% scatter t_max vs IDV for significant countries (dots)
scatter(X(:,2),X(:,4),'.')

% plot line of best fit
c = regress(X_all(:,2),[X_all(:,1), ones(length(X_all),1)]);
IDV = 20:100;
plot(IDV, IDV*c(1) + c(2),'LineWidth',1,'Color','black');

% axes labels
ylabel('Peak year ($t_{max}$)','FontSize',12,'Interpreter','Latex')
xlabel('Individualism (IDV)','FontSize',12,'Interpreter','Latex')
title('{\bf(d)}','FontSize',12)

% axes limits
xmin = 20; xmax = 100;
ymin = 1960; ymax = 2010;

axis([xmin xmax ymin ymax])

% axes position, labels, and ticks
set(gca,'FontSize',10)
set(gca, 'units', 'centimeters', 'pos', [1.75 1 6.5 6.75])
set(gca,'YTick', ymin:(ymax-ymin)/6:ymax)
set(gca,'YTickLabel',{num2str(ymin), '', '', num2str((ymax+ymin)/2), '', '', num2str(ymax)})

set(gca,'XTick', xmin:(xmax-xmin)/6:xmax)
set(gca,'XTickLabel',{num2str(xmin), '', '', num2str((xmax+xmin)/2), '', '', num2str(xmax)})

% add text identifiers
text(X(:,2)+1,X(:,4),P(:,1),'FontSize',10)

% scatter t_max vs IDV for non-significant countries (asterisks)
X_other = zeros(N-N_sig-1,2);     % [IDV, t_max]
names_other = cell(N-N_sig-1,1);
j = 1;

for i=1:N
    if ~sig_cty(i)
        X_other(j,1) = CandP{i,4};
        X_other(j,2) = CandP{i,5};
        names_other{j} = CandP{i,1};
        j = j+1;
    end
end

scatter(X_other(:,1), X_other(:,2),'*')

% add text identifiers
text(X_other(:,1)+1, X_other(:,2), names_other,'FontSize',10)

% Plot Figure 5: (a vs sx and a vs tmax)
figure
set(gcf, 'units', 'centimeters', 'pos', [1 1 8.7 15])
a = [Table_1{2:end-1,3}]';

% s_x vs a
subplot(2,1,1)
box on
hold on
scatter(a, s_x, '.')

% axes labels
ylabel('Average slope ($s_x$)','FontSize',12,'Interpreter','Latex')
xlabel('Relative conformity ($a$)','FontSize',12,'Interpreter','Latex')
title('{\bf(a)}','FontSize',12)

% axes limits
xmin = .9;
xmax = 1.2;
ymin = 0.001;
ymax = 0.008;

axis([xmin xmax ymin ymax])

% axes position, labels, and ticks

set(gca,'YTick', ymin:(ymax-ymin)/6:ymax)
set(gca,'YTickLabel',{num2str(ymin), '', '', num2str((ymax+ymin)/2), '', '', num2str(ymax)})

set(gca,'XTick', xmin:(xmax-xmin)/6:xmax)
set(gca,'XTickLabel',{num2str(xmin), '', '', num2str((xmax+xmin)/2), '', '', num2str(xmax)})

text(a+.02, s_x,P(:,1),'FontSize',10)

% plot line of best fit
c = regress(s_x,[a, ones(length(a),1)]);

plot(xmin:0.01:xmax, c(1)*(xmin:0.01:xmax) + c(2),'LineWidth',1,'Color','black');

% t_max vs a
subplot(2,1,2)
box on
hold on
scatter(a, [P{:,5}], '.')

% axes labels
ylabel('Peak year ($t_{max}$)','FontSize',12,'Interpreter','Latex')
xlabel('Relative conformity ($a$)','FontSize',12,'Interpreter','Latex')
title('{\bf(b)}','FontSize',12)

% axes limits
xmin = .9;
xmax = 1.2;
ymin = 1960;
ymax = 1990;

axis([xmin xmax ymin ymax])

% axes position, labels, and ticks

set(gca,'YTick', ymin:(ymax-ymin)/6:ymax)
set(gca,'YTickLabel',{num2str(ymin), '', '', num2str((ymax+ymin)/2), '', '', num2str(ymax)})

set(gca,'XTick', xmin:(xmax-xmin)/6:xmax)
set(gca,'XTickLabel',{num2str(xmin), '', '', num2str((xmax+xmin)/2), '', '', num2str(xmax)})

text(a+.02, [P{:,5}],P(:,1),'FontSize',10)

% plot line of best fit
c = regress([P{:,5}]',[a, ones(length(a),1)]);

plot(xmin:0.01:xmax, c(1)*(xmin:0.01:xmax) + c(2),'LineWidth',1,'Color','black');


% Plot Fig. 3: proxy data and discounting function
figure
set(gcf, 'units', 'centimeters', 'pos', [5 5 8.7 15])

% plot proxy data
subplot(2,1,1)

[AX, H1, H2] = plotyy(articles_Scopus(:,1), articles_Scopus(:,2),...
    articles_Scopus(:,1), articles_Scopus(:,3));

title('{\bf(a)}','FontSize', 12)

set(H1,'LineWidth',1)
set(H2,'LineWidth',1,'Color','black','Linestyle','--')

xmin = 1900; xmax = 2020; ymin = [0 0]; ymax = [700 12000];

axis(AX(1),[xmin xmax ymin(1) ymax(1)])
axis(AX(2),[xmin xmax ymin(2) ymax(2)])
set(AX(2),'YColor','black')

set(get(AX(1),'Ylabel'),'String','No. articles published','FontSize',12,'Interpreter','Latex')

set(get(AX(2),'Ylabel'),'String','Cum. no. articles published ($n(t)$)', 'FontSize',12,'Color','black','Interpreter','Latex')

set(get(AX(1),'Xlabel'),'String','Year','FontSize',12,'Interpreter','Latex')

set(AX(1),'FontSize',10,'XTick',xmin:(xmax-xmin)/6:xmax,'XTickLabel',...
    {num2str(xmin), '', '', '', '', '', num2str(xmax)})
set(AX(2),'FontSize',10,'XTick',xmin:(xmax-xmin)/6:xmax,'XTickLabel',...
    {num2str(xmin), '', '', '', '', '', num2str(xmax)})

set(AX(1),'FontSize',10,'YTick',ymin(1):(ymax(1)-ymin(1))/6:ymax(1),'YTickLabel',...
    {num2str(ymin(1)), '', '', num2str((ymax(1)+ymin(1))/2), '', '', num2str(ymax(1))})
set(AX(2),'FontSize',10,'YTick',ymin(2):(ymax(2)-ymin(2))/6:ymax(2),'YTickLabel',...
    {num2str(ymin(2)), '', '', num2str((ymax(2)+ymin(2))/2), '', '', num2str(ymax(2))})

% set(gca,'Position',[0.1 0.15 0.33 0.75])

% plot discounting function
subplot(2,1,2)
hold on
box on

% Choose delta, ux0, and ux1 for plotting 
% u_x(t) = ux1 + delta^(n(t)-1)*(ux0-ux1)
delta = [0.4 0.6 0.8 0.9 0.99 0.998 0.9995];
ux0 = 0.51;
ux1 = 0.49;

% styles for lines of different discounting deltas
sty = {'k-', 'k--', 'k:', 'b-', 'b--', 'b:', 'r-'};

for i=1:length(delta)
    plot(articles_Scopus(:,1), ux1 + delta(i).^(articles_Scopus(:,3) - 1)*(ux0 - ux1),sty{i},'LineWidth',1)
end

xlabel('Year','FontSize',12,'Interpreter','Latex')
ylabel('Individual utility ($u_x(t)$)','FontSize',12,'Interpreter','Latex')

xmin = 1900;
xmax = 2020;
ymin = 0.489;
ymax = 0.511;

axis([xmin xmax ymin ymax])

set(gca,'FontSize',10,'XTick',xmin:(xmax-xmin)/6:xmax,'XTickLabel',...
    {num2str(xmin), '', '', '', '', '', num2str(xmax)})

set(gca,'FontSize',10,'YTick',0.49:0.02/6:0.51,'YTickLabel',...
    {num2str(0.49), '', '', num2str(0.50), '', '', num2str(0.51)})

title('{\bf(b)}','FontSize',12)
x = [1910, 1910 1910 1910 1920 1970];
y = [0.493 0.497 0.502 0.5055 0.508 0.508];
tit = {'$\delta=0.4$', '$\delta=0.6$', '$\delta=0.8$', '$\delta=0.9$',...
    '$\delta=0.99$', '$\delta=0.9995$'};
text(x,y,tit,'FontSize',10,'Interpreter','Latex')

% set(gca,'Position',[0.63 0.15 0.33 0.75])

annotation('textarrow', [0.86 0.815], [0.6 0.6], 'String', '$\delta=0.998$', 'Interpreter', 'Latex')

%% Counterfactual for USA: what if USA had the same IDV as UK?
% Index of USA in Table A2
idx_USA = find(strcmp(CandP(:,1),'USA'),1);

% Find relative conformity for UK
idx_Gbr_P = find(strcmp(P(:,1),'GBR'),1);
acf = 0.974;

% Use US parameters for x0, b, u0, uinf, delta, use acf for relative
% conformity
paramcf = [Lparam(idx_USA_P,1), acf, Lparam(idx_USA_P,3:end)];

% Solve Eq. 1
[t,y] = ode45(@multi_smk, fit_sig{idx_USA_P}(:,1), paramcf);

% calculate cig/smoker/day = c/x = (1- B/x)/C
% (1 - B/mix{x(t)})/C => c/x => 1/C
csy = [(1 - Table_A2{idx_USA+1,4}/min(fit_sig{idx_USA_P}(1:91,2)))...
    /Table_A2{idx_USA+1,2}, 1/Table_A2{idx_USA+1,2}]*365;

csy_avg = mean(csy);

% Plot Fig. A.3: Counterfactual results
figure; box on; hold on;
plot(fit_sig{idx_USA_P}(1:91,1), csy_avg*fit_sig{idx_USA_P}(1:91,2).*USpop(:,2)/10^11,...
    t(1:91), csy_avg*y(1:91,1).*USpop(:,2)/10^11,'--')

% label axes
xlabel('Year','FontSize',12, 'Interpreter', 'Latex')
ylabel('Trillions of cig. smoked per year','FontSize',12, 'Interpreter', 'Latex')

% set limits and ticks for axes
xmin = 1920;
xmax = 2010;
ymin = 0;
ymax = 8;

axis([xmin, xmax, ymin, ymax])

set(gca,'XTick', xmin:15:xmax)
set(gca,'XTickLabel',{num2str(xmin), num2str(xmin + 15),...
    num2str(xmin + 30), num2str(xmin + 45), num2str(xmin + 60),...
    num2str(xmin + 75), num2str(xmin+90)})

% set size of figure and panels
set(gcf, 'units', 'centimeters', 'pos', [1 1 8.4 7])
set(gca, 'units', 'centimeters', 'pos', [1.5 1 6.5 5.5])

% compare area under the curve
US_diff = trapz(t(1:91), csy_avg*(y(1:91,1) - fit_sig{idx_USA_P}(1:91,2)).*USpop(:,2)/10^11);
US_diff_rel = US_diff/trapz(t(1:91), csy_avg*(fit_sig{idx_USA_P}(1:91,2)).*USpop(:,2)/10^11);